<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="es" sourcelanguage="en">
<context>
    <name>ArtisticSolidColor</name>
    <message>
        <source>Irregular</source>
        <translation>Irregular</translation>
    </message>
    <message>
        <source>Horiz Offset</source>
        <translation>Desplazamiento horiz.</translation>
    </message>
    <message>
        <source>Vert Offset</source>
        <translation>Desplazamiento vert.</translation>
    </message>
    <message>
        <source>Noise</source>
        <translation>Ruido</translation>
    </message>
</context>
<context>
    <name>FlowLineStrokeStyle</name>
    <message>
        <source>Density</source>
        <translation>Densidad</translation>
    </message>
    <message>
        <source>Extension</source>
        <translation>Extender</translation>
    </message>
    <message>
        <source>Width Scale</source>
        <translation>Escalar ancho</translation>
    </message>
    <message>
        <source>Straighten Ends</source>
        <translation>Enderezar extremos</translation>
    </message>
    <message>
        <source>Flow Line</source>
        <translation>Línea de flujo</translation>
    </message>
</context>
<context>
    <name>MovingSolidColor</name>
    <message>
        <source>Offset</source>
        <translation>Desplazamiento</translation>
    </message>
    <message>
        <source>Horiz Offset</source>
        <translation>Desplazamiento horiz.</translation>
    </message>
    <message>
        <source>Vert Offset</source>
        <translation>Desplazamiento vert.</translation>
    </message>
</context>
<context>
    <name>OutlineViewerStyle</name>
    <message>
        <source>OutlineViewer(OnlyDebug)</source>
        <translation>Visor de contornos (sólo depuración)</translation>
    </message>
    <message>
        <source>Control Point</source>
        <translation>Puntos de control</translation>
    </message>
    <message>
        <source>Center Line</source>
        <translation>Líneas</translation>
    </message>
    <message>
        <source>Outline Mode</source>
        <translation>Contornos</translation>
    </message>
    <message>
        <source>Distance</source>
        <translation>Distancia</translation>
    </message>
    <message>
        <source>distance</source>
        <translation>distancia</translation>
    </message>
</context>
<context>
    <name>ShadowStyle</name>
    <message>
        <source>Hatched Shading</source>
        <translation>Sombreado tramado</translation>
    </message>
    <message>
        <source>Angle</source>
        <translation>Ángulo</translation>
    </message>
    <message>
        <source>Density</source>
        <translation>Densidad</translation>
    </message>
    <message>
        <source>Length</source>
        <translation>Longitud</translation>
    </message>
</context>
<context>
    <name>ShadowStyle2</name>
    <message>
        <source>Plain Shadow</source>
        <translation>Sombra plena</translation>
    </message>
    <message>
        <source>Angle</source>
        <translation>Ángulo</translation>
    </message>
    <message>
        <source>Size</source>
        <translation>Tamaño</translation>
    </message>
</context>
<context>
    <name>TAirbrushRasterStyle</name>
    <message>
        <source>Airbrush</source>
        <translation>Aerógrafo</translation>
    </message>
    <message>
        <source>Blur value</source>
        <translation>Valor de desenfoque</translation>
    </message>
</context>
<context>
    <name>TBiColorStrokeStyle</name>
    <message>
        <source>Shade</source>
        <translation>Sombrear</translation>
    </message>
</context>
<context>
    <name>TBlendRasterStyle</name>
    <message>
        <source>Blend</source>
        <translation>Fundir</translation>
    </message>
</context>
<context>
    <name>TBlendStrokeStyle2</name>
    <message>
        <source>Fade</source>
        <translation>Desvanecer</translation>
    </message>
    <message>
        <source>Border Fade</source>
        <translation>Desvanecer borde</translation>
    </message>
    <message>
        <source>Fade In</source>
        <translation>Desvanecimiento entrante</translation>
    </message>
    <message>
        <source>Fade Out</source>
        <translation>Desvanecimiento saliente</translation>
    </message>
</context>
<context>
    <name>TBraidStrokeStyle</name>
    <message>
        <source>Plait</source>
        <translation>Trenzar</translation>
    </message>
    <message>
        <source>Twirl</source>
        <translation>Tornear</translation>
    </message>
</context>
<context>
    <name>TBubbleStrokeStyle</name>
    <message>
        <source>Bubbles</source>
        <translation>Burbujas</translation>
    </message>
</context>
<context>
    <name>TChainStrokeStyle</name>
    <message>
        <source>Chain</source>
        <translation>Cadena</translation>
    </message>
</context>
<context>
    <name>TChalkFillStyle</name>
    <message>
        <source>Chalk</source>
        <translation>Tiza</translation>
    </message>
    <message>
        <source>Density</source>
        <translation>Densidad</translation>
    </message>
    <message>
        <source>Dot Size</source>
        <translation>Tamaño del punto</translation>
    </message>
</context>
<context>
    <name>TChalkStrokeStyle2</name>
    <message>
        <source>Chalk</source>
        <translation>Tiza</translation>
    </message>
    <message>
        <source>Border Fade</source>
        <translation>Desvanecimiento del borde</translation>
    </message>
    <message>
        <source>Density</source>
        <translation>Densidad</translation>
    </message>
    <message>
        <source>Fade In</source>
        <translation>Desvanecimiento entrante</translation>
    </message>
    <message>
        <source>Fade Out</source>
        <translation>Desvanecimiento saliente</translation>
    </message>
    <message>
        <source>Noise</source>
        <translation>Ruido</translation>
    </message>
</context>
<context>
    <name>TCheckedFillStyle</name>
    <message>
        <source>Square</source>
        <translation>Cuadrado</translation>
    </message>
    <message>
        <source>Horiz Dist</source>
        <translation>Dist. horiz.</translation>
    </message>
    <message>
        <source>Horiz Angle</source>
        <translation>Ángulo horiz.</translation>
    </message>
    <message>
        <source>Vert Dist</source>
        <translation>Dist. vert.</translation>
    </message>
    <message>
        <source>Vert Angle</source>
        <translation>Ángulo vert.</translation>
    </message>
    <message>
        <source>Thickness</source>
        <translation>Grosor</translation>
    </message>
</context>
<context>
    <name>TChessFillStyle</name>
    <message>
        <source>Chessboard</source>
        <translation>Damero</translation>
    </message>
    <message>
        <source>Horiz Size</source>
        <translation>Tamaño horiz.</translation>
    </message>
    <message>
        <source>Vert Size</source>
        <translation>Tamaño vert.</translation>
    </message>
    <message>
        <source>Angle</source>
        <translation>Ángulo</translation>
    </message>
</context>
<context>
    <name>TCircleStripeFillStyle</name>
    <message>
        <source>Concentric</source>
        <translation>Concéntrico</translation>
    </message>
    <message>
        <source>X Position</source>
        <translation>Posición X</translation>
    </message>
    <message>
        <source>Y Position</source>
        <translation>Posición Y</translation>
    </message>
    <message>
        <source>Distance</source>
        <translation>Distancia</translation>
    </message>
    <message>
        <source>Thickness</source>
        <translation>Grosor</translation>
    </message>
</context>
<context>
    <name>TCrystallizeStrokeStyle</name>
    <message>
        <source>Tulle</source>
        <translation>Tul</translation>
    </message>
    <message>
        <source>Crease</source>
        <translation>Pliegue</translation>
    </message>
    <message>
        <source>Opacity</source>
        <translation>Opacidad</translation>
    </message>
</context>
<context>
    <name>TDottedFillStyle</name>
    <message>
        <source>Polka Dots</source>
        <translation>Lunares</translation>
    </message>
    <message>
        <source>Dot Size</source>
        <translation>Tamaño del punto</translation>
    </message>
    <message>
        <source>Dot Distance</source>
        <translation>Distancia entre puntos</translation>
    </message>
</context>
<context>
    <name>TDottedLineStrokeStyle</name>
    <message>
        <source>Vanishing</source>
        <translation>Esfumado</translation>
    </message>
    <message>
        <source>Fade In</source>
        <translation>Desvanecimiento entrante</translation>
    </message>
    <message>
        <source>Dash</source>
        <translation>Línea</translation>
    </message>
    <message>
        <source>Fade Out</source>
        <translation>Desvanecimiento saliente</translation>
    </message>
    <message>
        <source>Gap</source>
        <translation>Espacio</translation>
    </message>
</context>
<context>
    <name>TDualColorStrokeStyle2</name>
    <message>
        <source>Striped</source>
        <translation>Rayado</translation>
    </message>
    <message>
        <source>Distance</source>
        <translation>Distancia</translation>
    </message>
</context>
<context>
    <name>TFriezeStrokeStyle2</name>
    <message>
        <source>Curl</source>
        <translation>Enrulado</translation>
    </message>
    <message>
        <source>Twirl</source>
        <translation>Tornear</translation>
    </message>
    <message>
        <source>Thickness</source>
        <translation>Grosor</translation>
    </message>
</context>
<context>
    <name>TFurStrokeStyle</name>
    <message>
        <source>Herringbone</source>
        <translation>Espina de pescado</translation>
    </message>
    <message>
        <source>Angle</source>
        <translation>Ángulo</translation>
    </message>
    <message>
        <source>Size</source>
        <translation>Tamaño</translation>
    </message>
</context>
<context>
    <name>TGraphicPenStrokeStyle</name>
    <message>
        <source>Dashes</source>
        <translation>Guiones</translation>
    </message>
    <message>
        <source>Density</source>
        <translation>Densidad</translation>
    </message>
</context>
<context>
    <name>TLinGradFillStyle</name>
    <message>
        <source>Linear Gradient</source>
        <translation>Gradiente lineal</translation>
    </message>
    <message>
        <source>Angle</source>
        <translation>Ángulo</translation>
    </message>
    <message>
        <source>X Position</source>
        <translation>Posición X</translation>
    </message>
    <message>
        <source>Y Position</source>
        <translation>Posición Y</translation>
    </message>
    <message>
        <source>Smoothness</source>
        <translation>Suavizado</translation>
    </message>
</context>
<context>
    <name>TLongBlendStrokeStyle2</name>
    <message>
        <source>Watercolor</source>
        <translation>Acuarela</translation>
    </message>
    <message>
        <source>Distance</source>
        <translation>Distancia</translation>
    </message>
</context>
<context>
    <name>TMatrioskaStrokeStyle</name>
    <message>
        <source>Toothpaste</source>
        <translation>Pasta dental</translation>
    </message>
    <message>
        <source>Stripes</source>
        <translation>Rayas</translation>
    </message>
</context>
<context>
    <name>TMosaicFillStyle</name>
    <message>
        <source>Stained Glass</source>
        <translation>Vitral</translation>
    </message>
    <message>
        <source>Size</source>
        <translation>Tamaño</translation>
    </message>
    <message>
        <source>Distortion</source>
        <translation>Distorsión</translation>
    </message>
    <message>
        <source>Min Thick</source>
        <translation>Grosor mín.</translation>
    </message>
    <message>
        <source>Max Thick</source>
        <translation>Grosor máx.</translation>
    </message>
</context>
<context>
    <name>TMultiLineStrokeStyle2</name>
    <message>
        <source>Gouache</source>
        <translation>Gouache</translation>
    </message>
    <message>
        <source>Density</source>
        <translation>Densidad</translation>
    </message>
    <message>
        <source>Size</source>
        <translation>Tamaño</translation>
    </message>
    <message>
        <source>Thickness</source>
        <translation>Grosor</translation>
    </message>
    <message>
        <source>Noise</source>
        <translation>Ruido</translation>
    </message>
</context>
<context>
    <name>TNoColorRasterStyle</name>
    <message>
        <source>Markup</source>
        <translation>Demarcado</translation>
    </message>
</context>
<context>
    <name>TNormal2StrokeStyle</name>
    <message>
        <source>Bump</source>
        <translation>Relieve</translation>
    </message>
    <message>
        <source>Light X Pos</source>
        <translation>Pos. X de la luz</translation>
    </message>
    <message>
        <source>Light Y Pos</source>
        <translation>Pos. Y de la luz</translation>
    </message>
    <message>
        <source>Shininess</source>
        <translation>Brillo</translation>
    </message>
    <message>
        <source>Plastic</source>
        <translation>Plástico</translation>
    </message>
</context>
<context>
    <name>TPatchFillStyle</name>
    <message>
        <source>Beehive</source>
        <translation>Colmena</translation>
    </message>
    <message>
        <source>Size</source>
        <translation>Tamaño</translation>
    </message>
    <message>
        <source>Distortion</source>
        <translation>Distorsión</translation>
    </message>
    <message>
        <source>Thickness</source>
        <translation>Grosor</translation>
    </message>
</context>
<context>
    <name>TPointShadowFillStyle</name>
    <message>
        <source>Sponge Shading</source>
        <translation>Sombreado con esponja</translation>
    </message>
    <message>
        <source>Angle</source>
        <translation>Ángulo</translation>
    </message>
    <message>
        <source>Density</source>
        <translation>Densidad</translation>
    </message>
    <message>
        <source>Size</source>
        <translation>Tamaño</translation>
    </message>
    <message>
        <source>Point Size</source>
        <translation>Tamaño del punto</translation>
    </message>
</context>
<context>
    <name>TRadGradFillStyle</name>
    <message>
        <source>Radial Gradient</source>
        <translation>Gradiente radial</translation>
    </message>
    <message>
        <source>X Position</source>
        <translation>Posición X</translation>
    </message>
    <message>
        <source>Y Position</source>
        <translation>Posición Y</translation>
    </message>
    <message>
        <source>Radius</source>
        <translation>Radio</translation>
    </message>
    <message>
        <source>Smoothness</source>
        <translation>Suavizado</translation>
    </message>
</context>
<context>
    <name>TRopeStrokeStyle</name>
    <message>
        <source>Rope</source>
        <translation>Cuerda</translation>
    </message>
    <message>
        <source>Tilt</source>
        <translation>Inclinación</translation>
    </message>
</context>
<context>
    <name>TRubberFillStyle</name>
    <message>
        <source>Blob</source>
        <translation>Gota</translation>
    </message>
    <message>
        <source>Intensity</source>
        <translation>Intensidad</translation>
    </message>
</context>
<context>
    <name>TSawToothStrokeStyle</name>
    <message>
        <source>Jagged</source>
        <translation>Dentado</translation>
    </message>
    <message>
        <source>Distance</source>
        <translation>Distancia</translation>
    </message>
</context>
<context>
    <name>TSinStrokeStyle</name>
    <message>
        <source>Wave</source>
        <translation>Onda</translation>
    </message>
    <message>
        <source>Frequency</source>
        <translation>Frecuencia</translation>
    </message>
</context>
<context>
    <name>TSketchStrokeStyle</name>
    <message>
        <source>Fuzz</source>
        <translation>Desorden</translation>
    </message>
    <message>
        <source>Density</source>
        <translation>Densidad</translation>
    </message>
</context>
<context>
    <name>TSprayStrokeStyle</name>
    <message>
        <source>Circlets</source>
        <translation>Aros</translation>
    </message>
    <message>
        <source>Border Fade</source>
        <translation>Desvanecimiento del borde</translation>
    </message>
    <message>
        <source>Density</source>
        <translation>Densidad</translation>
    </message>
    <message>
        <source>Size</source>
        <translation>Tamaño</translation>
    </message>
</context>
<context>
    <name>TStripeFillStyle</name>
    <message>
        <source>Banded</source>
        <translation>A bandas</translation>
    </message>
    <message>
        <source>Distance</source>
        <translation>Distancia</translation>
    </message>
    <message>
        <source>Angle</source>
        <translation>Ángulo</translation>
    </message>
    <message>
        <source>Thickness</source>
        <translation>Grosor</translation>
    </message>
</context>
<context>
    <name>TTissueStrokeStyle</name>
    <message>
        <source>Gauze</source>
        <translation>Gasa</translation>
    </message>
    <message>
        <source>Density</source>
        <translation>Densidad</translation>
    </message>
    <message>
        <source>Border Size</source>
        <translation>Tamaño del borde</translation>
    </message>
</context>
<context>
    <name>TTwirlStrokeStyle</name>
    <message>
        <source>Ribbon</source>
        <translation>Cinta</translation>
    </message>
    <message>
        <source>Twirl</source>
        <translation>Tornear</translation>
    </message>
    <message>
        <source>Shade</source>
        <translation>Sombreado</translation>
    </message>
</context>
<context>
    <name>TZigzTSinStrokeStyleagStrokeStyle</name>
    <message>
        <source>Thickness</source>
        <translation>Grosor</translation>
    </message>
</context>
<context>
    <name>TZigzagStrokeStyle</name>
    <message>
        <source>Zigzag</source>
        <translation>Zigzag</translation>
    </message>
    <message>
        <source>Min Distance</source>
        <translation>Distancia mín.</translation>
    </message>
    <message>
        <source>Max Distance</source>
        <translation>Distancia máx.</translation>
    </message>
    <message>
        <source>Min Angle</source>
        <translation>Ángulo mín.</translation>
    </message>
    <message>
        <source>Max Angle</source>
        <translation>Ángulo máx.</translation>
    </message>
    <message>
        <source>Thickness</source>
        <translation>Grosor</translation>
    </message>
</context>
</TS>
